Module: CoderCompanion::VisualMessage
- Defined in:
- lib/codercompanion/visual_message.rb
Class Method Summary collapse
- .dry_run_text ⇒ Object
- .get_greeting_text ⇒ Object
- .supported_language_row(lang) ⇒ Object
- .supported_languages_header ⇒ Object
Class Method Details
.dry_run_text ⇒ Object
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/codercompanion/visual_message.rb', line 55 def self.dry_run_text return "\n\#{CoderCompanion.notification_format(\"Performing dry run:\")}\n - No cache use\n - No upload \n\n" end |
.get_greeting_text ⇒ Object
4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 |
# File 'lib/codercompanion/visual_message.rb', line 4 def self.get_greeting_text =begin ----------------------------------------------------------------------------------------------- __-¯--__ __-¯¯ ¯¯--__ __-¯¯ ¯¯-___, /¯-__ __-¯¯__ | | ¯¯--__ __-¯¯__-¯¯ | | | ¯--__-¯¯__-¯¯ | | | | r¯¯ ¯¯ | | | | | O | | L | | _-| | `~__ | | __-¯¯__-¯¯ `~__ | | __-¯¯__-¯¯ __-¯¯`~__ `~__ | '¯¯__-¯¯ __-¯¯ ;- `L_-¯¯ __-¯¯ __-¯¯ __-¯¯ __-¯¯ `~_ __-¯¯ `~__-¯¯ #{special_format("R u n n i n g C o d e r C o m p a n i o n u p l o a d e r")} ----------------------------------------------------------------------------------------------- =end return "-----------------------------------------------------------------------------------------------\n\n \#{::CoderCompanion.special_format(\"R u n n i n g C o d e r C o m p a n i o n u p l o a d e r\")}\n\n-----------------------------------------------------------------------------------------------\n" end |
.supported_language_row(lang) ⇒ Object
47 48 49 50 51 52 53 |
# File 'lib/codercompanion/visual_message.rb', line 47 def self.supported_language_row lang return "\nLanguage: \#{::CoderCompanion.notification_format(lang[:key])}\\t\\t|\\t Requires Annotations: \#{lang[:annotation_required] ? ::CoderCompanion.success_format(\"YES\") : ::CoderCompanion.red_format(\"NO\") }\\t\\t|\\tAnnotations Style(s): \#{(lang[:annotation_required]) ? ::CoderCompanion.notification_format(lang[:valid_annotation].join(\", \")) : ::CoderCompanion.notification_format(\"N/A\")}\n\n" end |
.supported_languages_header ⇒ Object
37 38 39 40 41 42 43 44 45 |
# File 'lib/codercompanion/visual_message.rb', line 37 def self.supported_languages_header return "-----------------------------------------------------------------------------------------------\n\n \#{CoderCompanion::notification_format(\"CoderCompanion Supported Languages (2015-05-30)\")}\n\n-----------------------------------------------------------------------------------------------\n" end |